@@ -81,15 +81,14 @@ class Proxy(proxy.Proxy):
         :param instance: This can be either the ID of an instance
                          or a :class:`~openstack.database.v1.instance.Instance`
                          instance that the interface belongs to.
-        :param kwargs \*\*query: Optional query parameters to be sent to limit
+        :param kwargs query: Optional query parameters to be sent to limit
                                  the resources being returned.
 
         :returns: A generator of database objects
         :rtype: :class:`~openstack.database.v1.database.Database`
         """
         instance = self._get_resource(_instance.Instance, instance)
-        return self._list(_database.Database, paginated=False,
-                          instance_id=instance.id, **query)
+        return self._list(_database.Database, instance_id=instance.id, **query)
 
     def get_database(self, database, instance=None):
         """Get a single database
@@ -137,13 +136,13 @@ class Proxy(proxy.Proxy):
     def flavors(self, **query):
         """Return a generator of flavors
 
-        :param kwargs \*\*query: Optional query parameters to be sent to limit
+        :param kwargs query: Optional query parameters to be sent to limit
                                  the resources being returned.
 
         :returns: A generator of flavor objects
         :rtype: :class:`~openstack.database.v1.flavor.Flavor`
         """
-        return self._list(_flavor.Flavor, paginated=False, **query)
+        return self._list(_flavor.Flavor, **query)
 
     def create_instance(self, **attrs):
         """Create a new instance from attributes
@@ -203,13 +202,13 @@ class Proxy(proxy.Proxy):
     def instances(self, **query):
         """Return a generator of instances
 
-        :param kwargs \*\*query: Optional query parameters to be sent to limit
+        :param kwargs query: Optional query parameters to be sent to limit
                                  the resources being returned.
 
         :returns: A generator of instance objects
         :rtype: :class:`~openstack.database.v1.instance.Instance`
         """
-        return self._list(_instance.Instance, paginated=False, **query)
+        return self._list(_instance.Instance, **query)
 
     def update_instance(self, instance, **attrs):
         """Update a instance
@@ -283,15 +282,14 @@ class Proxy(proxy.Proxy):
 
         :param instance: This can be either the ID of an instance
                          or a :class:`~openstack.database.v1.instance.Instance`
-        :param kwargs \*\*query: Optional query parameters to be sent to limit
+        :param kwargs query: Optional query parameters to be sent to limit
                                  the resources being returned.
 
         :returns: A generator of user objects
         :rtype: :class:`~openstack.database.v1.user.User`
         """
         instance = self._get_resource(_instance.Instance, instance)
-        return self._list(_user.User, instance_id=instance.id,
-                          paginated=False, **query)
+        return self._list(_user.User, instance_id=instance.id, **query)
 
     def get_user(self, user, instance=None):
         """Get a single user
